==> SD35B_0.02.1_src.tar.gz: Sd35b/decoder/MessageCtrl.h <==
/*
 * MessageCtrl.h - "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 */

#ifndef __MessageCtrl_h__
#define __MessageCtrl_h__
/**********************************************************************
	scenario decoder system message ctroller
**********************************************************************/
#include "ScenarioDecoderSystem.h"
//#include <string>
//
namespace ALSD {
	class CMessageCtrl;
};
//
namespace ALSD_MSGCTR {
	const unsigned long ALSD_MSGWINDOW_FRAME_EMPTY	= 0;
	const unsigned long ALSD_MSGWINDOW_FRAME_LINE	= 1;
	const unsigned long ALSD_MSGWINDOW_FRAME_CG		= 2;
	
	const unsigned long InfoMax = 128;
	struct stMessageInfo {
		long x, y, w, h, s;
	};
	const char *const lpPrompt = "";
};
//
namespace ALSD_FILECTR {
	struct stSaveHeader;
};
//
//
class ALSD::CMessageCtrl {
public:
	//
	CMessageCtrl( CScenarioDecoder *_lpScenarioDecoder );
	virtual ~CMessageCtrl();
	
	// 
	void Clear( bool _bClearFlag );
	void Message( const char *_lpMsg );
	void NextLine( void );
	void NextPage( void );
	void HitAnyKey( void );
	void UpdateGetMessage( long _sw );

	//
	void GetSaveData( ALSD_FILECTR::stSaveHeader *_lpSaveHeader );
	void SetLoadData( ALSD_FILECTR::stSaveHeader *_lpSaveHeader );

	// setting
	void SetMsgInfo( long _num, long _x, long _y, long _w, long _h, long _s );
	void ChangeMsg( long _num, long _w, long _c1, long c2, long _n, long _m );
	void SetLocate( long _x, long _y ){m_MsgPos.x = _x; m_MsgPos.y = _y; };
	void GetLocate( long*_x, long*_y ){*_x = m_MsgPos.x; *_y = m_MsgPos.y;};
	void SetFontSize ( long _size){ m_FontSize = _size;};
	void SetFontColor( long _c ){ m_FontColor = _c;};
	void SetFrameColor(long _c ){ m_FrameColor= _c;};
	void SetBackColor( long _c ){ m_BackColor = _c;};
	void SetClearAlpha ( long _c ){ m_MessageAlpha  = _c;};
	void SetMarkColor( long _c ){ m_AnyKeyColor=_c;};
	void SetHankaku  ( bool _bh){ m_bHankaku = _bh;};
	void SetOutput	 ( bool _sw){ m_bOutput  = _sw;};
	void SetGetMessage(bool _sw){ m_bGetMessage=_sw;};
	void SetGetMessageRUpdate( bool _sw ){ m_bMessageVarUpdateR = _sw;};
	void SetGetMessageAMode(   long _md ){ m_MessageVarUpdateA  = _md;};
	void SetGetMessageVarStart(long _no ){ m_MessageVarIndexStart=_no;};
	void SetGetMessageVarNow ( long _no ){ m_MessageVarIndexNow  =_no + m_MessageVarIndexStart;};
	void SetAutoNextPage( bool _sw ){ m_bAutoPageChange = _sw;};

	bool GetGetMessage( void )const { return m_bGetMessage;};
	long GetGetMessageVarNow ( void )const { return m_MessageVarIndexNow;};
	bool IsHankaku( void )const { return m_bHankaku;};

protected:
	//
	ALSD_MSGCTR::stMessageInfo m_lpMsgInfo[ALSD_MSGCTR::InfoMax];

	CScenarioDecoder	*m_lpSD;

	bool m_bClearFlag;
	bool m_bAutoPageChange;
	bool m_bHitAnyKey;
	bool m_bHankaku;
	bool m_bOutput;
	bool m_bGetMessage;
	bool m_bMessageVarUpdateR;
	long m_NowWindow;
	long m_FrameType;
	long m_FontSize;
	long m_LineIncrement;
	long m_CharIncrement;
	long m_MessageVarIndexStart;
	long m_MessageVarIndexNow;
	long m_MessageVarUpdateA;

	long m_SaveRectID;	// bZ[ẄҔID
	long m_MessageAlpha;// ftHg255/s

//	long m_ColorKey;
	long m_FontColor;
	long m_BackColor;
	long m_FrameColor;
	long m_AnyKeyColor;
	stGrpPoint	m_MsgPos;
	//
	void DrawLineFrame( void );
	void DrawMessage( const std::string &_Msg );
	void DrawPrompt ( void );
	void ErasePrompt( void );

private:
};

#endif

==> SD35B_0.02.2_src.tar.gz: Sd35b/decoder/MessageCtrl.h <==
/*
 * MessageCtrl.h - "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 */

#ifndef __MessageCtrl_h__
#define __MessageCtrl_h__
/**********************************************************************
	scenario decoder system message ctroller
**********************************************************************/
#include "ScenarioDecoderSystem.h"
//#include <string>
//
namespace ALSD {
	class CMessageCtrl;
};
//
namespace ALSD_MSGCTR {
	const unsigned long ALSD_MSGWINDOW_FRAME_EMPTY	= 0;
	const unsigned long ALSD_MSGWINDOW_FRAME_LINE	= 1;
	const unsigned long ALSD_MSGWINDOW_FRAME_CG		= 2;
	
	const unsigned long InfoMax = 128;
	struct stMessageInfo {
		long x, y, w, h, s;
	};
	const char *const lpPrompt = "";
};
//
namespace ALSD_FILECTR {
	struct stSaveHeader;
};
//
//
class ALSD::CMessageCtrl {
public:
	//
	CMessageCtrl( CScenarioDecoder *_lpScenarioDecoder );
	virtual ~CMessageCtrl();
	
	// 
	void Clear( bool _bClearFlag );
	void Message( const char *_lpMsg );
	void NextLine( void );
	void NextPage( void );
	void HitAnyKey( void );
	void UpdateGetMessage( long _sw );

	//
	void GetSaveData( ALSD_FILECTR::stSaveHeader *_lpSaveHeader );
	void SetLoadData( ALSD_FILECTR::stSaveHeader *_lpSaveHeader );

	// setting
	void SetMsgInfo( long _num, long _x, long _y, long _w, long _h, long _s );
	void ChangeMsg( long _num, long _w, long _c1, long c2, long _n, long _m );
	void SetLocate( long _x, long _y ){m_MsgPos.x = _x; m_MsgPos.y = _y; };
	void GetLocate( long*_x, long*_y ){*_x = m_MsgPos.x; *_y = m_MsgPos.y;};
	void SetFontSize ( long _size){ m_FontSize = _size;};
	void SetFontColor( long _c ){ m_FontColor = _c;};
	void SetFrameColor(long _c ){ m_FrameColor= _c;};
	void SetBackColor( long _c ){ m_BackColor = _c;};
	void SetClearAlpha ( long _c ){ m_MessageAlpha  = _c;};
	void SetMarkColor( long _c ){ m_AnyKeyColor=_c;};
	void SetHankaku  ( bool _bh){ m_bHankaku = _bh;};
	void SetOutput	 ( bool _sw){ m_bOutput  = _sw;};
	void SetGetMessage(bool _sw){ m_bGetMessage=_sw;};
	void SetGetMessageRUpdate( bool _sw ){ m_bMessageVarUpdateR = _sw;};
	void SetGetMessageAMode(   long _md ){ m_MessageVarUpdateA  = _md;};
	void SetGetMessageVarStart(long _no ){ m_MessageVarIndexStart=_no;};
	void SetGetMessageVarNow ( long _no ){ m_MessageVarIndexNow  =_no + m_MessageVarIndexStart;};
	void SetAutoNextPage( bool _sw ){ m_bAutoPageChange = _sw;};
	bool GetAutoNextPage( void ){ return m_bAutoPageChange;};
	bool GetAutoPageStop( void ){ return m_bAutoPageStop;};

	bool GetGetMessage( void )const { return m_bGetMessage;};
	long GetGetMessageVarNow ( void )const { return m_MessageVarIndexNow;};
	bool IsHankaku( void )const { return m_bHankaku;};

protected:
	//
	ALSD_MSGCTR::stMessageInfo m_lpMsgInfo[ALSD_MSGCTR::InfoMax];

	CScenarioDecoder	*m_lpSD;

	bool m_bAutoPageChange; // ̑I܂Ői
	bool m_bAutoPageStop;	// }EXNbNorIŁ

	bool m_bClearFlag;
	bool m_bHitAnyKey;
	bool m_bHankaku;
	bool m_bOutput;
	bool m_bGetMessage;
	bool m_bMessageVarUpdateR;
	long m_NowWindow;
	long m_FrameType;
	long m_FontSize;
	long m_LineIncrement;
	long m_CharIncrement;
	long m_MessageVarIndexStart;
	long m_MessageVarIndexNow;
	long m_MessageVarUpdateA;

	long m_SaveRectID;	// bZ[ẄҔID
	long m_MessageAlpha;// ftHg255/s

//	long m_ColorKey;
	long m_FontColor;
	long m_BackColor;
	long m_FrameColor;
	long m_AnyKeyColor;
	stGrpPoint	m_MsgPos;
	//
	void DrawLineFrame( void );
	void DrawMessage( const std::string &_Msg );
	void DrawPrompt ( void );
	void ErasePrompt( void );

private:
};

#endif
